@@ -74,6 +74,13 @@ public interface ISMTPProperties extends ITransportProperties {
      */
     public boolean isSmtpEnvelopeFrom();
 
+    /**
+     * Gets the logTransport flag
+     *
+     * @return the logTransport flag
+     */
+    public boolean isLogTransport();
+
     /**
      * Gets the smtpAuthEnc
      *
@@ -95,4 +102,18 @@ public interface ISMTPProperties extends ITransportProperties {
      */
     public int getSmtpConnectionTimeout();
 
+    /**
+     * Gets supported SSL protocols
+     * @return Supported SSL protocols
+     */
+    public String getSSLProtocols();
+
+    /**
+     * Gets the SSL cipher suites that will be enabled for SSL connections. The property value is a whitespace separated list of tokens
+     * acceptable to the <code>javax.net.ssl.SSLSocket.setEnabledProtocols</code> method.
+     *
+     * @return The SSL cipher suites
+     */
+    public String getSSLCipherSuites();
+
 }
