@@ -50,8 +50,6 @@
 package com.openexchange.smtp.config;
 
 import java.nio.charset.Charset;
-import org.apache.commons.logging.Log;
-import com.openexchange.log.LogFactory;
 import com.openexchange.mail.transport.config.MailAccountTransportProperties;
 import com.openexchange.mailaccount.MailAccount;
 
@@ -62,7 +60,7 @@ import com.openexchange.mailaccount.MailAccount;
  */
 public final class MailAccountSMTPProperties extends MailAccountTransportProperties implements ISMTPProperties {
 
-    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(MailAccountSMTPProperties.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(MailAccountSMTPProperties.class);
 
     private final MailAccount mailAccount;
 
@@ -88,8 +86,7 @@ public final class MailAccountSMTPProperties extends MailAccountTransportPropert
             return smtpAuthEncStr;
         }
         final String fallback = SMTPProperties.getInstance().getSmtpAuthEnc();
-        LOG.error(new StringBuilder(64).append("SMTP Auth Encoding: Unsupported charset \"").append(smtpAuthEncStr).append(
-            "\". Setting to fallback ").append(fallback));
+        LOG.error("SMTP Auth Encoding: Unsupported charset \"{}\". Setting to fallback {}", smtpAuthEncStr, fallback);
         return fallback;
     }
 
@@ -157,4 +154,41 @@ public final class MailAccountSMTPProperties extends MailAccountTransportPropert
         }
         return retval;
     }
+
+
+    @Override
+    public boolean isLogTransport() {
+        final boolean retval;
+        if (mailAccount.getId() == 0) {
+            final String tmp = properties.get("com.openexchange.smtp.logTransport");
+            if (null == tmp) {
+                return SMTPProperties.getInstance().isLogTransport();
+            }
+            retval = Boolean.parseBoolean(tmp);
+        } else {
+            retval = false;
+        }
+        return retval;
+    }
+
+    @Override
+    public String getSSLProtocols() {
+        final String tmp = properties.get("com.openexchange.smtp.ssl.protocols");
+        if (null == tmp) {
+            return SMTPProperties.getInstance().getSSLProtocols();
+        }
+
+        return tmp.trim();
+    }
+
+    @Override
+    public String getSSLCipherSuites() {
+        final String tmp = properties.get("com.openexchange.smtp.ssl.ciphersuites");
+        if (null == tmp) {
+            return SMTPProperties.getInstance().getSSLCipherSuites();
+        }
+
+        return tmp.trim();
+    }
+
 }
