@@ -56,6 +56,9 @@ import com.openexchange.exception.OXException;
 import com.openexchange.mail.api.MailCapabilities;
 import com.openexchange.mail.transport.config.ITransportProperties;
 import com.openexchange.mail.transport.config.TransportConfig;
+import com.openexchange.mail.utils.MailPasswordUtil;
+import com.openexchange.mailaccount.MailAccount;
+import com.openexchange.session.Session;
 import com.openexchange.smtp.SMTPExceptionCode;
 import com.openexchange.tools.net.URIDefaults;
 import com.openexchange.tools.net.URIParser;
@@ -159,4 +162,43 @@ public final class SMTPConfig extends TransportConfig {
     public void setTransportProperties(final ITransportProperties transportProperties) {
         this.transportProperties = (ISMTPProperties) transportProperties;
     }
+
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    protected boolean doCustomParsing(MailAccount account, Session session) throws OXException {
+        if (!account.isDefaultAccount()) {
+            login = account.getTransportLogin();
+
+            if (seemsNotSet(login)) {
+                // Fallback to mail account credentials
+                login = account.getLogin();
+                password = MailPasswordUtil.decrypt(account.getPassword(), session, account.getId(), login, account.getMailServer());
+            } else {
+                String tpwd = account.getTransportPassword();
+                if (com.openexchange.java.Strings.isEmpty(tpwd)) {
+                    password = MailPasswordUtil.decrypt(account.getPassword(), session, account.getId(), login, account.getMailServer());
+                } else {
+                    password = MailPasswordUtil.decrypt(tpwd, session, account.getId(), login, account.getTransportServer());
+                    if (seemsNotSet(password)) {
+                        password = MailPasswordUtil.decrypt(account.getPassword(), session, account.getId(), login, account.getMailServer());
+                    }
+                }
+            }
+
+            return true;
+        }
+        return false;
+    }
+
+    private static boolean seemsNotSet(final String str) {
+        if (com.openexchange.java.Strings.isEmpty(str)) {
+            return true;
+        }
+
+        final String lc = com.openexchange.java.Strings.toLowerCase(str);
+        return "null".equals(lc) || "nil".equals(lc);
+    }
+
 }
