@@ -52,6 +52,7 @@ package com.openexchange.smtp.config;
 import java.nio.charset.Charset;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.Strings;
 import com.openexchange.mail.api.AbstractProtocolProperties;
 import com.openexchange.mail.transport.config.ITransportProperties;
 import com.openexchange.mail.transport.config.TransportProperties;
@@ -64,7 +65,7 @@ import com.openexchange.smtp.services.Services;
  */
 public final class SMTPProperties extends AbstractProtocolProperties implements ISMTPProperties {
 
-    private static final org.apache.commons.logging.Log LOG = com.openexchange.log.Log.valueOf(com.openexchange.log.LogFactory.getLog(SMTPProperties.class));
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(SMTPProperties.class);
 
     private static final SMTPProperties instance = new SMTPProperties();
 
@@ -95,6 +96,12 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
 
     private int smtpConnectionTimeout;
 
+    private boolean logTransport;
+
+    private String sslProtocols;
+
+    private String cipherSuites;
+
     /**
      * Initializes a new {@link SMTPProperties}
      */
@@ -127,6 +134,12 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
             logBuilder.append("\tSet SMTP ENVELOPE-FROM: ").append(smtpEnvelopeFrom).append('\n');
         }
 
+        {
+            final String tmp = configuration.getProperty("com.openexchange.smtp.logTransport", "false").trim();
+            logTransport = Boolean.parseBoolean(tmp);
+            logBuilder.append("\tLog transport: ").append(logTransport).append('\n');
+        }
+
         {
             final String smtpAuthEncStr = configuration.getProperty("com.openexchange.smtp.smtpAuthEnc", "UTF-8").trim();
             if (Charset.isSupported(smtpAuthEncStr)) {
@@ -165,11 +178,17 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
             }
         }
 
-        logBuilder.append("Global SMTP properties successfully loaded!");
-        if (LOG.isInfoEnabled()) {
-            LOG.info(logBuilder.toString());
+        sslProtocols = configuration.getProperty("com.openexchange.smtp.ssl.protocols", "SSLv3 TLSv1").trim();
+        logBuilder.append("\tSupported SSL protocols: ").append(sslProtocols).append("\n");
+
+        {
+            final String tmp = configuration.getProperty("com.openexchange.smtp.ssl.ciphersuites", "").trim();
+            this.cipherSuites = Strings.isEmpty(tmp) ? null : tmp;
+            logBuilder.append("\tSupported SSL cipher suites: ").append(null == this.cipherSuites ? "<default>" : cipherSuites).append("\n");
         }
 
+        logBuilder.append("Global SMTP properties successfully loaded!");
+        LOG.info(logBuilder.toString());
     }
 
     @Override
@@ -180,6 +199,9 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         smtpAuthEnc = null;
         smtpTimeout = 0;
         smtpConnectionTimeout = 0;
+        logTransport = false;
+        sslProtocols = "SSLv3 TLSv1";
+        cipherSuites = null;
     }
 
     @Override
@@ -197,6 +219,11 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         return smtpEnvelopeFrom;
     }
 
+    @Override
+    public boolean isLogTransport() {
+        return logTransport;
+    }
+
     @Override
     public String getSmtpAuthEnc() {
         return smtpAuthEnc;
@@ -217,4 +244,14 @@ public final class SMTPProperties extends AbstractProtocolProperties implements
         return transportProperties.getReferencedPartLimit();
     }
 
+    @Override
+    public String getSSLProtocols() {
+        return sslProtocols;
+    }
+
+    @Override
+    public String getSSLCipherSuites() {
+        return cipherSuites;
+    }
+
 }
